@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkDirectedAcyclicGraph extends vtkDirectedGraph
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -25,7 +25,7 @@ public class vtkDirectedAcyclicGraph extends vtkDirectedGraph
 
     if (temp == 0) return null;
     return (vtkDirectedAcyclicGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetData_4(vtkInformationVector id0,int id1);
   public vtkDirectedAcyclicGraph GetData(vtkInformationVector id0,int id1) {
@@ -33,7 +33,7 @@ public class vtkDirectedAcyclicGraph extends vtkDirectedGraph
 
     if (temp == 0) return null;
     return (vtkDirectedAcyclicGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   public vtkDirectedAcyclicGraph() { super(); }
 
