@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkInformationStringKey extends vtkInformationKey
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -21,7 +21,7 @@ public class vtkInformationStringKey extends vtkInformationKey
 
     if (temp == 0) return null;
     return (vtkInformationStringKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void Set_3(vtkInformation id0,String id1);
   public void Set(vtkInformation id0,String id1)
